@@ -78,13 +78,32 @@ def parse_video_info(raw_info):
             for item in
                 raw_info.split('&')])
 
+# Signature decryption algorithm, reused code from youtube-dl
+def decrypt_signature(s):
+    if len(s) == 88:
+        return s[48] + s[81:67:-1] + s[82] + s[66:62:-1] + s[85] + s[61:48:-1] + s[67] + s[47:12:-1] + s[3] + s[11:3:-1] + s[2] + s[12]
+    elif len(s) == 87:
+        return s[62] + s[82:62:-1] + s[83] + s[61:52:-1] + s[0] + s[51:2:-1]
+    elif len(s) == 86:
+        return s[2:63] + s[82] + s[64:82] + s[63]
+    elif len(s) == 85:
+        return s[76] + s[82:76:-1] + s[83] + s[75:60:-1] + s[0] + s[59:50:-1] + s[1] + s[49:2:-1]
+    elif len(s) == 84:
+        return s[83:36:-1] + s[2] + s[35:26:-1] + s[3] + s[25:3:-1] + s[26]
+    elif len(s) == 83:
+        return s[52] + s[81:55:-1] + s[2] + s[54:52:-1] + s[82] + s[51:36:-1] + s[55] + s[35:2:-1] + s[36]
+    elif len(s) == 82:
+        return s[36] + s[79:67:-1] + s[81] + s[66:40:-1] + s[33] + s[39:36:-1] + s[40] + s[35] + s[0] + s[67] + s[32:0:-1] + s[34]
+    else:
+        raise Exception('Unable to decrypt signature, key length %d not supported; retrying might work' % (len(s)))
+
 def youtube_download_by_id(id, title = None, output_dir = '.', merge = True, info_only = False):
     
     raw_info = request.urlopen('http://www.youtube.com/get_video_info?video_id=%s' % id).read().decode('utf-8')
     
     video_info = parse_video_info(raw_info)
     
-    if video_info['status'] == 'ok': # use get_video_info data
+    if video_info['status'] == 'ok' and not video_info['use_cipher_signature'] == 'True': # use get_video_info data
         
         title = parse.unquote(video_info['title'].replace('+', ' '))
         
@@ -118,7 +137,7 @@ def youtube_download_by_id(id, title = None, output_dir = '.', merge = True, inf
                 url = r1(r'url=([^\\]+)', fmt)
                 url = unicodize(url)
                 url = parse.unquote(url)
-                sig = r1(r'sig=([^\\]+)', fmt)
+                sig = r1(r'sig=([^\\]+)', fmt) or decrypt_signature(r1(r's=([^\\]+)', fmt))
                 url = url + '&signature=' + sig
                 break
         try:
